pub struct Blake2s { /* private fields */ }Expand description
Blake2s Context
Implementations
Sourceimpl Blake2s
impl Blake2s
Sourcepub fn new(outlen: usize) -> Self
pub fn new(outlen: usize) -> Self
Create a new Blake2s context with a specific output size in bytes
the size need to be between 0 (non included) and 32 bytes (included)
Sourcepub fn new_keyed(outlen: usize, key: &[u8]) -> Self
pub fn new_keyed(outlen: usize, key: &[u8]) -> Self
Similar to new but also takes a variable size key
to tweak the context initialization
Sourcepub fn reset_with_key(&mut self, key: &[u8])
pub fn reset_with_key(&mut self, key: &[u8])
Reset the blake2 context with a key