Choice

Struct Choice 

pub struct Choice(/* private fields */);
Constant time boolean

This implementation uses a u64 under the hood, but it’s never exposed and only used through abstraction that push toward more constant time operations.

Choice can be combined with simple And operation.

Choice can be converted back to a boolean operations, although once this is done, the operation will likely be non-constant.

Implementations

Source

impl Choice

pub fn is_true(self) -> bool

Return true if the Choice represent true

pub fn is_false(self) -> bool

return true if the Choice represent false

pub fn negate(self) -> Self

Toggle the value represented by the Choice in constant time

true become false, false become true