pub struct Context384(/* private fields */);Expand description
Keccak384 Context
Implementations
Sourceimpl Context384
impl Context384
Sourcepub fn update_mut(&mut self, data: &[u8])
pub fn update_mut(&mut self, data: &[u8])
Update in-place the hashing state by adding the input bytes slice into the state
For the immutable version see [update]
Sourcepub fn update(self, data: &[u8]) -> Self
pub fn update(self, data: &[u8]) -> Self
Update the hashing state by adding the input bytes slice into the state
Sourcepub fn finalize_reset(&mut self) -> [u8; 48]
pub fn finalize_reset(&mut self) -> [u8; 48]
Same as finalize but do not consume the context, but instead
reset it in a ready to use state.