Sha224

Struct Sha224 

pub struct Sha224;
Hash Algorithm

Implementations

Source

impl Sha224

pub const OUTPUT_BITS: usize = 224

Output of the hashing algorithm in bits

pub const BLOCK_BYTES: usize = 64

The block size in bytes of the algorithm, which is the number of bytes the algorithm typically buffer before calling its compression function

pub fn new() -> Context224

Create a new context for this algorithm