pub struct Sha3_224;Expand description
SHA3 224 Algorithm
Implementations
Sourceimpl Sha3_224
impl Sha3_224
Sourcepub const OUTPUT_BITS: usize
pub const OUTPUT_BITS: usize
Output of the hashing algorithm in bits
Sourcepub const BLOCK_BYTES: usize
pub const BLOCK_BYTES: usize
The block size in bytes of the algorithm, which is the number of bytes the algorithm typically buffer before calling its compression function
Sourcepub fn new() -> Context224
pub fn new() -> Context224
Create a new context for this algorithm