pub struct ChaChaOriginal<const ROUNDS: usize> { /* private fields */ }Expand description
ChaCha Context (Original version - Bernstein & co)
This variant has an 8 bytes nonce initializer, and an 8 bytes counter
Note that the number of rounds is exposed here, and only the value of 8, 12 and 20 are supported. any other values triggers a runtime assertion.
If you don’t know what round values to use, use 20
Implementations
Sourceimpl<const ROUNDS: usize> ChaChaOriginal<ROUNDS>
impl<const ROUNDS: usize> ChaChaOriginal<ROUNDS>
Sourcepub fn new(key: &[u8], nonce: &[u8; 8]) -> Self
pub fn new(key: &[u8], nonce: &[u8; 8]) -> Self
Create a new ChaCha20 context.
- The key must be 16 or 32 bytes
- The nonce must be 8 bytes
For using 12 bytes (96 bits) nonces, uses the IETF variant ChaCha
Sourcepub fn process_mut(&mut self, data: &mut [u8])
pub fn process_mut(&mut self, data: &mut [u8])
Process the input in place through the cipher xoring
To get only the stream of this cipher, one can just pass the zero buffer (X xor 0 = X)