pub struct Choice(/* private fields */);Expand description
Constant time boolean
This implementation uses a u64 under the hood, but it’s never exposed and only used through abstraction that push toward more constant time operations.
Choice can be combined with simple And operation.
Choice can be converted back to a boolean operations, although once this is done, the operation will likely be non-constant.
Implementations