pub struct Sha224;Expand description
Hash Algorithm
Implementations
Sourceimpl Sha224
impl Sha224
Sourcepub const OUTPUT_BITS: usize = 224
pub const OUTPUT_BITS: usize = 224
Output of the hashing algorithm in bits
Sourcepub const BLOCK_BYTES: usize = 64
pub const BLOCK_BYTES: usize = 64
The block size in bytes of the algorithm, which is the number of bytes the algorithm typically buffer before calling its compression function
Sourcepub fn new() -> Context224
pub fn new() -> Context224
Create a new context for this algorithm